@@ -13,7 +13,9 @@
 # Standard library
 # ----------------
 
+import datetime
 import os
+import re
 import subprocess
 import sys
 from pathlib import Path
@@ -33,7 +35,7 @@ from runestone.pretext.chapter_pop import manifest_data_to_db
 
 # Build a Runestone Book
 # ----------------------
-def _build_runestone_book(course, click=click):
+def _build_runestone_book(config, course, click=click):
     """
     Parameters:
     course: the name of the course to build.
@@ -41,13 +43,10 @@ def _build_runestone_book(course, click=click):
     """
     try:
         if os.path.exists("pavement.py"):
-            sys.path.insert(0, os.getcwd())
             # Since this may be used in a long running process (see AuthorServer/worker)
-            # we need to re-import to get the right values
-            if "pavement" in globals():
-                importlib.reload(pavement)
-            else:
-                import pavement
+            # using import is a bad idea, exec can be dangerous as well
+            paver_vars = {}
+            exec(open("pavement.py").read(), paver_vars)
         else:
             click.echo(
                 "I can't find a pavement.py file in {} you need that to build".format(
@@ -60,10 +59,10 @@ def _build_runestone_book(course, click=click):
         print(e)
         return False
 
-    if pavement.project_name != course:
+    if paver_vars["project_name"] != course:
         click.echo(
             "Error: {} and {} do not match.  Your course name needs to match the project_name in pavement.py".format(
-                course, pavement.project_name
+                course, paver_vars["project_name"]
             )
         )
         return False
@@ -80,7 +79,7 @@ def _build_runestone_book(course, click=click):
         )
         return False
     click.echo("Build succeedeed... Now deploying to published")
-    if pavement.dest != "./published":
+    if paver_vars["dest"] != "./published":
         click.echo(
             "Incorrect deployment directory.  dest should be ./published in pavement.py"
         )
@@ -93,11 +92,13 @@ def _build_runestone_book(course, click=click):
         olfile.write(res.stderr)
     if resd.returncode == 0:
         click.echo("Success! Book deployed")
-        return True
     else:
         click.echo("Deploy failed, check the log to see what went wrong.")
         return False
 
+    update_library(config, "", course, click, build_system="Runestone")
+    return True
+
 
 # Build a PreTeXt Book
 # --------------------
@@ -110,6 +111,7 @@ def _build_ptx_book(config, gen, manifest, course, click=click):
     course: the name of the course to build.
     click: default is the click module otherwise an object that has an echo method
     """
+
     if not os.path.exists("project.ptx"):
         click.echo("PreTeXt books need a project.ptx file")
         return False
@@ -155,7 +157,8 @@ def _build_ptx_book(config, gen, manifest, course, click=click):
         populate_static(config, mpath, course)
         # update the library page
         click.echo("updating library...")
-        update_library(config, mpath, course)
+        main_page = find_real_url(cname)
+        update_library(config, mpath, course, main_page=main_page, build_system="PTX")
         return True
 
 
@@ -228,7 +231,9 @@ def extract_docinfo(tree, string, attr=None, click=click):
     return ""
 
 
-def update_library(config, mpath, course, click=click):
+def update_library(
+    config, mpath, course, click=click, build_system="", main_page="index.html"
+):
     """
     Parameters:
     config : This originated as a config object from click -- a mock config will be provided by the AuthorServer
@@ -239,39 +244,100 @@ def update_library(config, mpath, course, click=click):
 
     Returns: Nothing
     """
-    tree = ET.parse(mpath)
-    docinfo = tree.find("./library-metadata")
     eng = create_engine(config.dburl)
-    title = extract_docinfo(docinfo, "title")
-    subtitle = extract_docinfo(docinfo, "subtitle")
-    description = extract_docinfo(docinfo, "blurb")
-    shelf = extract_docinfo(docinfo, "shelf")
+    if build_system == "PTX":
+        tree = ET.parse(mpath)
+        docinfo = tree.find("./library-metadata")
+        title = extract_docinfo(docinfo, "title")
+        subtitle = extract_docinfo(docinfo, "subtitle")
+        description = extract_docinfo(docinfo, "blurb")
+        shelf = extract_docinfo(docinfo, "shelf")
+    else:
+        try:
+            config_vars = {}
+            exec(open("conf.py").read(), config_vars)
+        except Exception as e:
+            print(f"Error adding book {course} to library list: {e}")
+            return
+        subtitle = ""
+        if "navbar_title" in config_vars:
+            title = config_vars["navbar_title"]
+        elif "html_title" in config_vars:
+            title = config_vars["html_title"]
+        elif "html_short_title" in config_vars:
+            title = config_vars["html_short_title"]
+        else:
+            title = "Runestone Book"
+        # update course description if found in the book's conf.py
+        if "course_description" in config_vars:
+            description = config_vars["course_description"]
+        else:
+            description = ""
+        # update course key_words if found in book's conf.py
+        if "key_words" in config_vars:
+            key_words = config_vars["key_words"]
+
+        if "shelf_section" in config_vars:
+            shelf = config_vars["shelf_section"]
+        else:
+            shelf = "Computer Science"
+
     click.echo(f"{title} : {subtitle}")
+
     try:
         res = eng.execute(f"select * from library where basecourse = '{course}'")
     except:
         click.echo("Missing library table?  You may need to run an alembic migration.")
         return False
 
+    build_time = datetime.datetime.utcnow()
+    click.echo("BUILD time is {build_time}")
     if res.rowcount == 0:
         eng.execute(
-            f"""insert into library 
-        (title, subtitle, description, shelf_section, basecourse ) 
-        values('{title}', '{subtitle}', '{description}', '{shelf}', '{course}') """
+            f"""insert into library
+        (title, subtitle, description, shelf_section, basecourse,
+            build_system, main_page, last_build )
+        values('{title}', '{subtitle}', '{description}', '{shelf}', '{course}',
+        '{build_system}', '{main_page}', '{build_time}') """
         )
     else:
+        # If any values are missing or null do not override them here.
+        #
+        res = res.first()
+        if not title:
+            title = res.title or ""
+        if not subtitle:
+            subtitle = res.subtitle or ""
+        if not description:
+            description = res.description or ""
+        if not shelf:
+            shelf = res.shelf_section or "Misc"
+        click.echo("Updating library")
         eng.execute(
             f"""update library set
             title = '{title}',
             subtitle = '{subtitle}',
             description = '{description}',
-            shelf_section = '{shelf}'
+            shelf_section = '{shelf}',
+            build_system = '{build_system}',
+            main_page = '{main_page}',
+            last_build = '{build_time}'
         where basecourse = '{course}'
         """
         )
     return True
 
 
+def find_real_url(book):
+    idx = Path("published", book, "index.html")
+    if idx.exists():
+        with open(idx, "r") as idxf:
+            for line in idxf:
+                if g := re.search(r"refresh.*URL='(.*?)'", line):
+                    return g.group(1)
+    return "index.html"
+
+
 def populate_static(config, mpath: Path, course: str, click=click):
     """
     Copy the apropriate Javascript to the _static folder for PreTeXt books.  This may
@@ -294,9 +360,11 @@ def populate_static(config, mpath: Path, course: str, click=click):
     # Do not download if the versions already match.
     if version != current_version:
         click.echo(f"Fetching {version} files to {sdir} ")
+        # remove the old files, but keep the lunr-pretext-search-index.js file if it exists
         for f in os.listdir(sdir):
             try:
-                os.remove(sdir / f)
+                if "lunr-pretext" not in f:
+                    os.remove(sdir / f)
             except:
                 click.echo(f"ERROR - could not delete {f}")
         # call wget non-verbose, recursive, no parents, no hostname, no directoy copy files to sdir
